@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.011-15-g3489902
+package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.012-6-g82e45e2
 # ABSTRACT: Add contributor names from git to your distribution
 # KEYWORDS: plugin distribution metadata git contributors authors commits
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
@@ -14,7 +14,6 @@ use List::Util 1.33 'none';
 use Git::Wrapper 0.035;
 use Try::Tiny;
 use Path::Tiny 0.048;
-use Data::Dumper;
 use Moose::Util::TypeConstraints 'enum';
 use Unicode::Collate 0.53;
 use namespace::autoclean;
@@ -115,7 +114,7 @@ sub _contributors
     my @contributors = map { utf8::decode($_); m/^\s*\d+\s*(.*)$/g; } @data;
 
     $self->log_debug([ 'extracted contributors from git: %s',
-        sub { Data::Dumper->new([ \@contributors ])->Indent(2)->Terse(1)->Dump } ]);
+        sub { require Data::Dumper; Data::Dumper->new([ \@contributors ])->Indent(2)->Terse(1)->Dump } ]);
 
     @contributors = Unicode::Collate->new(level => 1)->sort(@contributors) if $self->order_by eq 'name';
 
@@ -124,7 +123,7 @@ sub _contributors
         my @author_emails = map { /(<[^>]+>)/g } @{ $self->zilla->authors };
         @contributors = grep {
             my $contributor = $_;
-            none { $contributor =~ /$_/ } @author_emails;
+            none { $contributor =~ /\Q$_\E/ } @author_emails;
         } @contributors;
     }
 
@@ -136,7 +135,7 @@ sub _contributors
     if ($self->remove)
     {
         @contributors = grep {
-            my $contributor = $_; none { $contributor =~ /$_/ } $self->remove
+            my $contributor = $_; none { $contributor =~ /\Q$_\E/ } $self->remove
         } @contributors;
     }
 
@@ -202,7 +201,7 @@ Dist::Zilla::Plugin::Git::Contributors - Add contributor names from git to your
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
